<CsoundSynthesizer>
<CsOptions>
-odac
</CsOptions>

<CsInstruments>

;;;; *************** Drums and Different Canons *************
;;;;
;;;; Orchestra file for Grunenberg

sr      =       44100
kr      =       4410
ksmps   =       10
nchnls  =       2

gasnd   init    0

instr 4,5

;Start  dur     baseamp ampinc  Noise/cps       loc       Timbre
;p2     p3      p4      p5      p6              p7        p8
; The only difference between the two drums here is the base frequency

        if p1==5 igoto high
        ;; Instrument 4
                i2 = cpspch(p8) ; 11; 12.5
                igoto common

high:   ;; Instrument 5
                i2 = cpspch(20)

common:
        i1 = 1/p3               ; once per duration - for envelopes
        i3 = (p4+p5)            ; these three assignments balance the three
        i4 = (p4+p5)/3          ; branches of the drum instrument
        i5 = (p4+p5)/2.1        ;

                                ; branch 1 - NOISE
a1      oscili  i3,i1,2         ; generate steep exponential envelope
a1      randi   a1,p6/2         ; generate band of noise with freq. given by p5
a1      oscili  a1,500,4        ; use noise band for amp input - ring mod.

                                ; branch 2 - INHARM
a2      oscili  i4,i1,2         ; steep envelope with lower amplitude than a1
a2      oscili  a2,i2*.1,3      ; generate inharmonic partials - 1,1.6,2.2,2.3

                                ; branch 3 - FUND
a3      oscili  i5,i1,1         ; decay of f1 is less steep than f2
a3      oscili  a3,i2,4         ; generates fundamental tone

                                ; global envelope to prevent clicking
a4      linseg  1,p3-.05,1,.05,0,.01,0
a5  =   a4*(a1+a2+a3)
a6  =   a5*p7
a7  =   a5*(1-p7)
        outs a6, a7
        ;; Delay these signals to provide a little of the effect
a8      delay1 a7*p7
a9      delay1 a7*(1-p7)
        outs a8, a9
gasnd   =       gasnd + a5 * 0.25
endin

instr 6
;; The parameter i2 seems to control basic sound type
;;              15.2 has a metalic ring 15.1 is more wooden
;;              15.0 is rather like 15.1
        i2 = cpspch(15.1+p5/1000)
        i1 = 1/p3               ; once per duration - for envelopes
        i3 = p4                 ; these three assignments balance the three
        i4 = p4                 ; branches of the drum instrument
        i5 = p4/6.25
                                ; branch 1 - NOISE
a1      oscili  i3,i1,2         ; generate steep exponential envelope
a1      randi   a1,p5/2         ; generate band of noise with freq. given by p5
a1      oscili  a1,500,4        ; use noise band for amp input - ring mod.

                                ; branch 2 - INHARM
a2      oscili  i4,i1,2         ; steep envelope with lower amplitude than a1
a2      oscili  a2,i2*.2,3      ; generate inharmonic partials - 1,1.6,2.2,2.3

                                ; branch 3 - FUND
a3      oscili  i5,i1,1         ; decay of f1 is less steep than f2
a3      oscili  a3,i2,4         ; generates fundamental tone

                                ; global envelope to prevent clicking
a4      linseg  1,p3-.05,1,.05,0,.01,0
a5  =   a4*(a1+a2+a3)
a6  =   a5*p6
a7  =   a5*(1-p6)
        outs a6, a7
        ;; Delay these signals to provide a little of the effect
a8      delay1 a7*p6
a9      delay1 a7*(1-p6)
        outs a8, a9
gasnd   =       gasnd + a5 * 0.1
endin

instr   99
asig    reverb  gasnd, p4
        outs    asig, asig
gasnd   =       0
endin



</CsInstruments>

<CsScore>

;;;; Gruneberg.sco

; amp envelopes
f1 0 1024 5 1 1024 .004
f2 0 1024 5 1 1024 .00012

; waveforms
f3 0 1024 9 10 1 0 16 1.5 0 22 2 0 23 1.5 0
f4 0 1024 9 1 1 0

t0 600

;i4/5   Start   dur     baseamp ampinc  Noise           loc             Timbre
;i9     Start   dur     amp     Noise           loc

i99     1       766     0.8
i99     766     150     20

i6      1.000   0.652   7000    967             0.37
i6      1.652   0.895   7000    974             0.37
i6      2.547   0.591   7000    977             0.37
i6      3.138   0.389   7000    979             0.37
i6      3.527   0.347   7000    960             0.37
i6      3.874   0.436   7000    963             0.37
i6      4.310   0.700   7000    968             0.37
i4      1       3       200     10800   770             1.00            6
i4      1       3       >       0       1010            <               >
i4      4       3       >       0       674             <               >
i4      4       3       >       5000    1028            <               >
i4      7       3       >       0       592             <               >
i4      7       3       >       0       903             <               >
i4      11      3       >       6800    853             <               >
i4      12      3       >       0       1009            <               >
i4      14      3       >       0       701             <               >
i4      15      3       >       0       1054            <               >
i4      17      3       >       5000    519             <               >
i4      18      3       >       0       727             <               >
i4      20      3       >       10800   924             <               >
i4      21      3       >       0       859             <               >
i4      22      3       >       0       1010            <               >
i4      25      3       >       5000    699             <               >
i4      25      3       >       0       1053            <               >
i4      29      3       >       0       521             <               >
i4      32      3       >       6800    734             <               >
i4      32      3       >       0       928             <               >
i4      33      3       >       0       854             <               >
i4      34      3       >       0       1016            <               >
i4      37      3       >       5000    681             <               >
i4      37      3       >       0       1038            <               >
i4      40      3       >       10800   564             <               >
i4      42      3       >       0       844             <               >
i4      42      3       >       0       916             <               >
i4      43      3       >       0       907             <               >
i4      44      3       >       5000    944             <               >
i4      46      3       >       0       875             <               >
i4      47      3       >       0       999             <               >
i4      49      3       >       6800    737             <               >
i4      49      3       >       0       1072            <               >
i4      52      3       >       0       468             0.00            >
i6      54.000  1.462   7000    1131            0.62
i6      55.462  1.300   7000    1113            0.62
i6      56.762  1.325   7000    1115            0.62
i6      57.088  1.548   7000    1119            0.62
i6      58.636  1.816   7000    1126            0.62
i6      59.452  1.512   7000    1130            0.62
i6      60.964  1.324   7000    1113            0.62
i4      56      3       >       5000    567             0.00            >
i4      58      3       >       0       680             >               >
i4      59      3       >       0       901             >               >
i4      60      3       >       10800   882             >               >
i4      61      3       >       0       976             >               >
i4      63      3       >       0       795             >               >
i4      63      3       >       0       1068            >               >
i4      66      3       >       5000    499             1.00            >
i6      68.000  0.661   7000    982             0.21
i6      68.661  0.906   7000    989             0.21
i6      69.567  0.590   7000    993             0.21
i6      70.57   0.432   7000    975             0.21
i6      70.589  0.508   7000    978             0.21
i6      71.097  0.812   7000    985             0.21
i6      71.909  0.800   7000    991             0.21
i4      71      3       >       0       672             1.00            >
i4      71      3       >       6800    872             <               >
i4      71      3       >       0       919             <               >
i4      72      3       >       0       911             <               >
i4      73      3       >       0       939             <               >
i4      75      3       >       5000    885             <               >
i4      76      3       >       0       983             <               >
i4      78      3       >       0       780             <               >
i4      78      3       >       0       1073            <               >
i4      81      3       >       10800   476             0.00            >
i6      83.000  1.679   7000    998             0.51
i6      84.679  1.835   7000    1002            0.51
i6      86.515  2.154   7000    1009            0.51
i6      88.668  1.919   7000    1014            0.51
i6      90.587  1.679   7000    1016            0.51
i6      92.266  1.646   7000    998             0.51
i6      93.913  1.809   7000    1002            0.51
i4      84      3       >       0       596             0.00            >
i4      86      3       >       5000    746             >               >
i4      86      3       >       0       954             >               >
i4      86      3       >       0       804             >               >
i4      88      3       >       0       1058            >               >
i4      91      3       >       6800    535             >               >
i4      93      3       >       0       774             >               >
i4      93      3       >       0       939             >               >
i4      95      3       >       5000    844             >               >
i4      96      3       >       0       1029            >               >
i4      98      3       >       0       641             >               >
i4      99      3       >       10800   991             >               >
i4      101     3       >       0       687             >               >
i4      102     3       >       0       1036            >               >
i4      105     3       >       5000    572             >               >
i4      107     3       >       0       862             >               >
i4      108     3       >       0       901             >               >
i4      109     3       >       6800    937             >               >
i4      111     3       >       0       887             >               >
i4      112     3       >       0       981             >               >
i4      114     3       >       5000    786             >               >
i4      114     3       >       0       1072            >               >
i4      118     3       >       0       484             1.00            >
i6      120.000 1.395   7000    1133            0.47
i6      121.395 1.133   7000    1135            0.47
i6      122.528 1.050   7000    1116            0.47
i6      123.578 1.104   7000    1118            0.47
i6      124.681 1.327   7000    1122            0.47
i6      126.009 1.614   7000    1129            0.47
i6      126.623 1.323   7000    1133            0.47
i4      120     3       >       10800   622             1.00            >
i4      121     3       >       0       797             <               >
i4      121     3       >       0       962             <               >
i4      123     3       >       5000    804             <               >
i4      123     3       >       0       1061            <               >
i4      126     3       >       0       527             <               >
i4      129     3       >       6800    753             <               >
i4      129     3       >       0       935             <               >
i4      131     3       >       0       845             <               >
i4      131     3       >       0       1027            <               >
i4      134     3       >       5000    648             <               >
i4      135     3       >       0       1001            <               >
i4      137     3       >       0       663             <               >
i4      137     3       >       10800   1012            <               >
i4      141     3       >       0       635             <               >
i4      142     3       >       0       976             <               >
i4      144     3       >       5000    721             <               >
i4      144     3       >       0       1058            <               >
i4      147     3       >       0       512             <               >
i4      150     3       >       6800    708             <               >
i4      150     3       >       0       910             <               >
i4      151     3       >       0       877             <               >
i4      152     3       >       5000    985             <               >
i4      154     3       >       0       773             <               >
i4      154     3       >       0       1074            <               >
i4      155     3       >       10800   470             0.00            >
i6      159.000 1.597   7000    960             0.20
i6      160.597 1.683   7000    962             0.20
i6      162.280 1.950   7000    967             0.20
i6      164.231 2.147   7000    974             0.20
i6      166.378 1.821   7000    977             0.20
i6      168.200 1.663   7000    959             0.20
i6      169.863 1.704   7000    962             0.20
i4      160     3       >       0       577             0.00            >
i4      162     3       >       0       703             >               >
i4      162     3       >       5000    926             >               >
i4      163     3       >       0       849             >               >
i4      163     3       >       0       1021            >               >
i4      166     3       >       0       667             >               >
i4      166     3       >       6800    1024            >               >
i4      169     3       >       0       604             >               >
i4      172     3       >       5000    925             >               >
i4      173     3       >       0       820             >               >
i4      173     3       >       0       1042            >               >
i4      176     3       >       0       594             >               >
i4      178     3       >       10800   910             >               >
i4      179     3       >       0       842             >               >
i4      179     3       >       0       1022            >               >
i4      182     3       >       5000    662             >               >
i4      183     3       >       0       1018            >               >
i4      186     3       >       0       620             >               >
i4      187     3       >       6800    953             >               >
i4      187     3       >       0       769             >               >
i4      189     3       >       0       1065            >               >
i4      192     3       >       5000    502             >               >
i4      195     3       >       0       680             >               >
i4      196     3       >       0       883             >               >
i4      197     3       >       10800   909             >               >
i4      198     3       >       0       931             >               >
i4      200     3       >       0       900             >               >
i4      201     3       >       5000    960             >               >
i4      203     3       >       0       839             >               >
i4      203     3       >       0       1040            >               >
i4      206     3       >       6800    607             >               >
i4      208     3       >       0       935             >               >
i4      209     3       >       0       802             >               >
i4      210     3       >       0       1054            >               >
i4      213     3       >       5000    550             >               >
i4      215     3       >       0       812             >               >
i4      215     3       >       0       934             >               >
i4      217     3       >       10800   866             >               >
i4      218     3       >       0       1005            >               >
i4      220     3       >       0       717             >               >
i4      220     3       >       5000    1064            >               >
i4      223     3       >       0       489             1.00            >
i6      224.000 1.293   7000    1071            0.42
i6      225.293 0.963   7000    1075            0.42
i6      226.256 0.828   7000    1057            0.42
i6      227.084 0.940   7000    1061            0.42
i6      228.024 1.268   7000    1068            0.42
i6      229.292 1.119   7000    1073            0.42
i6      230.410 0.842   7000    1076            0.42
i4      226     3       >       6800    638             1.00            >
i4      227     3       >       0       824             <               >
i4      227     3       >       0       953             <               >
i4      229     3       >       0       830             <               >
i4      229     3       >       0       1044            <               >
i4      232     3       >       5000    590             <               >
i4      234     3       >       0       904             <               >
i4      235     3       >       10800   851             <               >
i4      236     3       >       0       1012            <               >
i4      239     3       >       0       693             <               >
i4      239     3       >       0       1048            <               >
i4      242     3       >       5000    535             <               >
i4      244     3       >       0       772             <               >
i4      244     3       >       0       940             <               >
i4      246     3       >       6800    843             <               >
i4      246     3       >       0       1030            <               >
i4      249     3       >       0       638             <               >
i4      250     3       >       5000    986             <               >
i4      252     3       >       0       697             <               >
i4      253     3       >       0       1044            <               >
i4      255     3       >       10800   550             <               >
i4      257     3       >       0       810             <               >
i4      257     3       >       0       935             <               >
i4      259     3       >       5000    864             <               >
i4      260     3       >       0       1008            <               >
i4      262     3       >       0       707             <               >
i4      262     3       >       0       1058            <               >
i4      265     3       >       6800    507             <               >
i4      268     3       >       0       692             <               >
i4      268     3       >       0       896             <               >
i4      269     3       >       5000    894             <               >
i4      270     3       >       0       958             <               >
i4      272     3       >       0       842             <               >
i4      272     3       >       0       1036            <               >
i4      275     3       >       10800   618             <               >
i4      276     3       >       0       956             <               >
i4      278     3       >       5000    763             <               >
i4      278     3       >       0       1065            <               >
i4      281     3       >       0       499             0.00            >
i6      283.000 0.444   7000    967             0.46
i6      283.444 0.776   7000    974             0.46
i6      284.220 0.625   7000    979             0.46
i6      284.845 0.338   7000    981             0.46
i6      285.183 0.239   7000    962             0.46
i6      285.422 0.279   7000    964             0.46
i6      285.701 0.485   7000    968             0.46
i4      284     3       >       6800    669             0.00            >
i4      285     3       >       0       869             >               >
i4      286     3       >       0       922             >               >
i4      287     3       >       0       904             >               >
i4      288     3       >       5000    951             >               >
i4      290     3       >       0       859             >               >
i4      291     3       >       0       1018            >               >
i4      294     3       >       10800   679             >               >
i4      295     3       >       0       1036            >               >
i4      298     3       >       5000    570             >               >
i4      300     3       >       0       856             >               >
i4      301     3       >       0       907             >               >
i4      302     3       >       0       926             >               >
i4      303     3       >       6800    909             >               >
i4      305     3       >       0       945             >               >
i4      306     3       >       0       873             >               >
i4      307     3       >       5000    1000            >               >
i4      309     3       >       0       733             >               >
i4      309     3       >       0       1071            >               >
i4      312     3       >       10800   471             1.00            >
i6      314.000 1.404   7000    1137            0.04
i6      315.404 1.152   7000    1139            0.04
i6      316.557 1.058   7000    1140            0.04
i6      317.615 1.055   7000    1121            0.04
i6      318.670 1.141   7000    1123            0.04
i6      319.811 1.379   7000    1127            0.04
i6      321.191 1.672   7000    1134            0.04
i4      315     3       >       0       578             1.00            >
i4      317     3       >       0       706             <               >
i4      318     3       >       5000    928             <               >
i4      318     3       >       0       844             <               >
i4      318     3       >       0       1025            <               >
i4      321     3       >       0       653             <               >
i4      322     3       >       6800    1006            <               >
i4      324     3       >       0       650             <               >
i4      325     3       >       0       997             <               >
i4      327     3       >       5000    675             <               >
i4      328     3       >       0       1025            <               >
i4      331     3       >       0       602             <               >
i4      332     3       >       10800   923             <               >
i4      334     3       >       0       824             <               >
;e
i4      335     3       >       0       1039            <               >
i4      337     3       >       5000    605             <               >
i4      339     3       >       0       932             <               >
i4      341     3       >       0       808             <               >
i4      341     3       >       6800    1050            <               >
i4      344     3       >       0       563             <               >
i4      346     3       >       0       845             <               >
i4      346     3       >       5000    915             <               >
i4      347     3       >       0       909             <               >
i4      348     3       >       0       940             <               >
i4      350     3       >       0       883             <               >
i4      351     3       >       10800   987             <               >
i4      353     3       >       0       769             <               >
i4      353     3       >       0       1075            <               >
i4      356     3       >       5000    466             0.00            12.5
i6      358.000 1.482   7000    1043            0.86
i6      359.482 1.399   7000    1024            0.86
i6      360.881 1.401   7000    1025            0.86
i6      362.282 1.490   7000    1027            0.86
i6      363.772 1.732   7000    1031            0.86
i6      365.504 2.023   7000    1038            0.86
i6      367.527 1.712   7000    1042            0.86
i4      359     3       >       0       564             0.00            <
i4      361     3       >       6800    672             >               <
i4      362     3       >       0       892             >               <
i4      363     3       >       0       894             >               <
i4      364     3       >       0       957             >               <
i4      366     3       >       5000    843             >               <
i4      366     3       >       0       1035            >               <
i4      369     3       >       0       622             >               <
i4      370     3       >       10800   962             >               <
i4      372     3       >       0       751             >               <
i4      372     3       >       0       1065            >               <
i4      375     3       >       5000    495             1.00            <
i6      377.000 1.548   7000    953             0.05
i6      378.548 1.582   7000    954             0.05
i6      380.130 1.748   7000    957             0.05
i6      381.878 2.083   7000    963             0.05
i6      383.961 1.986   7000    969             0.05
i6      385.947 1.675   7000    971             0.05
i6      387.622 1.524   7000    972             0.05
i4      378     3       >       0       658             1.00            <
i4      379     3       >       0       854             <               <
i4      380     3       >       6800    935             <               <
i4      382     3       >       0       877             <               <
i4      383     3       >       0       993             <               <
i4      385     3       >       5000    752             <               <
i4      385     3       >       0       1075            <               <
i4      386     3       >       0       462             0.00            <
i6      390.000 3.353   7000    1545            0.07
i6      393.353 3.183   7000    1543            0.07
i6      396.536 2.854   7000    1537            0.07
i6      399.390 2.866   7000    1531            0.07
i6      402.256 3.192   7000    1528            0.07
i6      405.448 3.361   7000    1528            0.07
i6      408.809 1.450   7000    1528            0.07
i4      391     3       >       10800   548             0.00            <
i4      393     3       >       0       630             >               <
i4      394     3       >       0       829             >               <
i4      394     3       >       0       948             >               <
i4      396     3       >       5000    843             >               <
i4      396     3       >       0       1032            >               <
i4      399     3       >       0       631             >               <
i4      400     3       >       6800    976             >               <
i4      402     3       >       0       721             >               <
i4      402     3       >       0       1058            >               <
i4      405     3       >       5000    512             >               <
i4      408     3       >       0       710             >               <
i4      408     3       >       0       911             >               <
i4      409     3       >       10800   875             >               <
i4      410     3       >       0       988             >               <
i4      412     3       >       0       765             >               <
i4      412     3       >       0       1075            >               <
i4      415     3       >       5000    465             1.00            <
i6      417.000 0.466   7000    940             0.32
i6      417.466 0.806   7000    946             0.32
i6      418.272 0.633   7000    951             0.32
i6      418.905 0.330   7000    953             0.32
i6      419.234 2.153   7000    953             0.32
i6      421.387 1.975   7000    951             0.32
i6      423.362 1.670   7000    946             0.32
i4      418     3       >       0       559             1.00            <
i4      420     3       >       6800    659             <               <
i4      421     3       >       0       876             <               <
i4      422     3       >       0       912             <               <
i4      423     3       >       0       924             <               <
i4      424     3       >       5000    914             <               <
i4      425     3       >       0       936             <               <
i4      427     3       >       0       893             <               <
i4      428     3       >       10800   971             <               <
i4      430     3       >       0       811             <               <
i4      430     3       >       0       1061            <               <
i4      433     3       >       5000    530             <               <
i4      436     3       >       0       760             <               <
i4      436     3       >       0       937             <               <
i4      438     3       >       6800    844             <               <
i4      438     3       >       0       1028            <               <
i4      441     3       >       0       643             <               <
i4      442     3       >       0       993             <               <
i4      444     3       >       5000    682             <               <
i4      445     3       >       0       1032            <               <
i4      448     3       >       10800   583             <               <
i4      450     3       >       0       885             <               <
i4      451     3       >       0       876             <               <
i4      452     3       >       0       979             <               <
i4      454     3       >       5000    787             <               <
i4      454     3       >       0       1071            <               <
i4      455     3       >       0       487             0.00            <
i6      457.000 2.075   7000    1326            0.42
i6      459.075 2.279   7000    1325            0.42
i6      463.354 2.382   7000    1325            0.42
i6      465.736 0.483   7000    1326            0.42
i6      466.219 0.679   7000    1329            0.42
i6      466.897 1.021   7000    1335            0.42
i6      467.918 0.890   7000    1340            0.42
i4      460     3       >       6800    634             0.00            <
i4      461     3       >       0       817             >               <
i4      462     3       >       0       956             >               <
i4      463     3       >       5000    821             >               <
i4      463     3       >       0       1050            >               <
i4      466     3       >       0       566             >               <
i4      468     3       >       10800   852             >               <
i4      469     3       >       0       909             >               <
i4      470     3       >       0       922             >               <
i4      471     3       >       0       918             >               <
i4      472     3       >       5000    928             >               <
i4      473     3       >       0       908             >               <
i4      474     3       >       0       946             >               <
i4      476     3       >       6800    871             >               <
i4      477     3       >       0       1004            >               <
i4      479     3       >       0       722             >               <
i4      479     3       >       0       1067            >               <
i4      482     3       >       5000    482             1.00            <
i6      484.000 1.373   7000    978             0.57
i6      485.373 3.197   7000    976             0.57
i6      488.570 2.895   7000    972             0.57
i6      491.465 2.703   7000    965             0.57
i6      494.168 3.046   7000    962             0.57
i6      497.214 3.253   7000    961             0.57
i6      500.467 3.352   7000    961             0.57
i4      485     3       >       0       616             1.00            <
i4      486     3       >       10800   784             <               <
i4      486     3       >       0       962             <               <
i4      486     3       >       0       798             <               <
i4      488     3       >       0       1063            <               <
i4      491     3       >       5000    517             <               <
i4      494     3       >       0       726             <               <
i4      494     3       >       0       923             <               <
i4      495     3       >       6800    860             <               <
i4      496     3       >       0       1008            <               <
i4      498     3       >       0       706             <               <
i4      498     3       >       0       1058            <               <
i4      501     3       >       5000    508             <               <
i4      504     3       >       0       697             <               <
i4      504     3       >       0       901             <               <
i4      505     3       >       10800   888             <               <
i4      506     3       >       0       967             <               <
i4      508     3       >       0       818             <               <
i4      508     3       >       0       1056            <               <
i4      512     3       >       5000    549             <               <
i4      513     3       >       0       811             <               <
i4      513     3       >       0       934             <               <
i4      515     3       >       6800    865             <               <
i4      516     3       >       0       1006            <               <
i4      518     3       >       0       713             <               <
i4      518     3       >       5000    1062            <               <
i4      521     3       >       0       495             0.00            <
i6      523.000 0.343   7000    926             0.32
i6      523.343 0.665   7000    932             0.32
i6      524.007 0.738   7000    938             0.32
i6      524.745 0.398   7000    941             0.32
i6      525.143 0.232   7000    942             0.32
i6      525.375 0.189   7000    923             0.32
i6      525.564 0.226   7000    924             0.32
i4      524     3       >       10800   657             0.00            <
i4      525     3       >       0       853             >               <
i4      526     3       >       0       936             >               <
i4      528     3       >       0       874             >               <
i4      529     3       >       5000    997             >               <
i4      531     3       >       0       741             >               <
i4      531     3       >       0       1073            >               <
i4      534     3       >       6800    465             1.00            <
i6      536.000 0.916   7000    995             0.26
i6      536.916 0.894   7000    1000            0.26
i6      537.810 0.565   7000    1003            0.26
i6      538.375 0.412   7000    1004            0.26
i6      538.787 0.361   7000    984             0.26
i6      539.148 0.363   7000    985             0.26
i6      539.510 0.418   7000    986             0.26
i4      537     3       >       0       558             1.00            <
i4      539     3       >       5000    657             <               <
i4      540     3       >       0       872             <               <
i4      541     3       >       0       915             <               <
i4      542     3       >       0       918             <               <
i4      543     3       >       10800   925             <               <
i4      544     3       >       0       914             <               <
i4      545     3       >       0       936             <               <
i4      547     3       >       0       892             <               <
i4      548     3       >       5000    973             <               <
i4      550     3       >       0       805             <               <
i4      550     3       >       0       1064            <               <
i4      553     3       >       6800    517             <               <
i4      556     3       >       0       724             <               <
i4      556     3       >       0       922             <               <
i4      557     3       >       5000    862             <               <
i4      558     3       >       0       1006            <               <
i4      560     3       >       0       712             <               <
i4      560     3       >       0       1061            <               <
i4      563     3       >       10800   498             0.00            <
i6      565.000 0.931   7000    995             0.10
i6      565.931 0.890   7000    1001            0.10
i6      566.820 0.561   7000    1004            0.10
i6      567.381 0.399   7000    1004            0.10
i6      567.781 2.318   7000    1004            0.10
i6      570.098 2.232   7000    1003            0.10
i6      572.331 2.057   7000    1001            0.10
i4      566     3       >       0       666             0.00            <
i4      567     3       >       5000    866             >               <
i4      568     3       >       0       925             >               <
i4      569     3       >       0       898             >               <
i4      570     3       >       0       961             >               <
i4      571     3       >       6800    836             >               <
i4      572     3       >       0       1041            >               <
i4      575     3       >       0       600             >               <
i4      577     3       >       5000    923             >               <
i4      578     3       >       0       823             >               <
i4      578     3       >       0       1040            >               <
i4      581     3       >       10800   602             >               <
i4      583     3       >       0       925             >               <
i4      584     3       >       0       819             >               <
i4      584     3       >       0       1043            >               <
i4      587     3       >       5000    590             >               <
i4      589     3       >       0       903             >               <
i4      590     3       >       0       853             >               <
i4      591     3       >       6800    1010            >               <
i4      594     3       >       0       698             >               <
i4      594     3       >       0       1052            >               <
i4      597     3       >       5000    525             >               <
i4      600     3       >       0       744             >               <
i4      600     3       >       0       932             >               <
i4      602     3       >       10800   848             >               <
i4      602     3       >       0       1023            >               <
i4      605     3       >       0       661             >               <
i4      606     3       >       5000    1016            >               <
i4      609     3       >       0       624             >               <
i4      610     3       >       0       960             >               <
i4      612     3       >       6800    756             >               <
i4      612     3       >       0       1066            >               <
i4      615     3       >       0       495             1.00            <
i6      617.000 2.157   7000    1342            0.19
i6      619.157 2.490   7000    1340            0.19
i6      621.646 2.663   7000    1339            0.19
i6      624.310 0.779   7000    1340            0.19
i6      625.089 0.951   7000    1342            0.19
i6      626.040 1.282   7000    1347            0.19
i6      627.322 1.334   7000    1354            0.19
i4      618     3       >       5000    659             1.00            <
i4      619     3       >       0       856             <               <
i4      620     3       >       0       934             <               <
i4      622     3       >       10800   879             <               <
i4      623     3       >       0       990             <               <
i4      624     3       >       0       761             <               <
i4      625     3       >       5000    1075            <               <
i4      628     3       >       0       463             0.00            <
i6      630.000 1.466   7000    1003            0.43
i6      631.466 1.383   7000    1003            0.43
i6      632.849 3.309   7000    1003            0.43
i6      636.158 3.166   7000    1001            0.43
i6      639.324 2.858   7000    996             0.43
i6      642.182 2.706   7000    989             0.43
i6      644.888 3.056   7000    986             0.43
i4      629     3       >       6800    551             0.00            <
i4      633     3       >       0       639             >               <
i4      634     3       >       0       845             >               <
i4      634     3       >       0       938             <               <
i4      636     3       >       5000    867             >               <
i4      637     3       >       0       1005            >               <
i4      639     3       >       0       717             >               <
i4      639     3       >       0       1064            >               <
i4      642     3       >       10800   489             1.00            <
i6      644.000 1.852   7000    1499            0.18
i6      645.852 1.694   7000    1496            0.18
i6      647.546 1.345   7000    1489            0.18
i6      648.891 1.467   7000    1484            0.18
i6      650.358 1.782   7000    1482            0.18
i6      652.140 1.925   7000    1481            0.18
i6      654.064 1.986   7000    1481            0.18
i4      645     3       >       0       639             1.00            <
i4      646     3       >       5000    825             <               <
i4      646     3       >       0       953             <               <
i4      648     3       >       0       832             <               <
i4      648     3       >       0       1042            <               <
i4      651     3       >       6800    596             <               <
i4      654     3       >       0       914             <               <
i4      654     3       >       0       836             <               <
i4      654     3       >       5000    1028            <               <
i4      657     3       >       0       642             <               <
i4      658     3       >       0       992             <               <
i4      660     3       >       10800   684             <               <
i4      661     3       >       0       1034            <               <
i4      664     3       >       0       579             <               <
i4      666     3       >       5000    876             <               <
i4      667     3       >       0       887             <               <
i4      668     3       >       0       962             <               <
i4      670     3       >       6800    831             <               <
i4      670     3       >       0       1046            <               <
i4      673     3       >       0       585             <               <
i4      675     3       >       5000    892             <               <
i4      676     3       >       0       867             <               <
i4      677     3       >       0       991             <               <
i4      679     3       >       10800   753             <               <
i4      679     3       >       0       1075            <               <
;; Out of range 0 10
i4      682     3       >       0       463             0.00            <
i6      684.000 0.53    7000    910             0.05
i6      684.153 0.333   7000    913             0.05
i6      684.485 0.683   7000    920             0.05
i6      685.168 0.590   7000    925             0.05
i6      685.759 0.263   7000    927             0.05
i6      686.021 0.088   7000    927             0.05
i6      686.110 1.952   7000    926             0.05
i4      685     3       >       5000    552             0.00            <
i4      687     3       >       0       641             >               <
i4      688     3       >       0       847             >               <
i4      688     3       >       0       937             >               <
i4      690     3       >       6800    871             >               <
i4      691     3       >       0       1000            >               <
i4      693     3       >       0       732             >               <
i4      693     3       >       5000    1070            >               <
i4      696     3       >       0       472             1.00            <
i6      698.000 2.405   7000    1433            0.41
i6      700.405 2.643   7000    1428            0.41
i6      703.048 2.945   7000    1427            0.41
i6      705.993 1.141   7000    1427            0.41
i6      707.134 1.387   7000    1430            0.41
i6      708.521 1.738   7000    1437            0.41
i6      710.259 1.530   7000    1441            0.41
i4      699     3       >       10800   582             1.00            <
i4      701     3       >       0       715             <               <
i4      701     3       >       0       936             <               <
i4      703     3       >       0       832             <               <
i4      703     3       >       5000    1037            <               <
i4      706     3       >       0       613             <               <
i4      707     3       >       0       945             <               <
i4      709     3       >       6800    783             <               <
i4      709     3       >       0       1062            <               <
i4      712     3       >       0       518             <               <
i4      715     3       >       5000    726             <               <
i4      715     3       >       0       923             <               <
i4      716     3       >       0       860             <               <
i4      717     3       >       0       1009            <               <
i4      718     3       >       10800   704             <               <
i4      719     3       >       0       1056            <               <
i4      721     3       >       0       512             <               <
i4      725     3       >       5000    706             <               <
i4      725     3       >       0       909             <               <
i4      726     3       >       0       879             <               <
i4      727     3       >       6800    983             <               <
i4      729     3       >       0       779             <               <
i4      729     3       >       0       1073            <               <
i4      732     3       >       5000    476             0.00            <
i6      734.000 3.218   7000    956             0.78
; Out of range 0 28
i6      737.218 2.905   7000    952             0.78
i6      740.123 2.663   7000    945             0.78
i6      742.786 3.010   7000    942             0.78
i6      745.796 3.267   7000    941             0.78
i6      749.063 1.471   7000    943             0.78
i6      750.534 1.783   7000    947             0.78
i4      735     3       >       0       596             1.00            <
i4      737     3       >       0       744             0.00            <
i4      737     3       >       10800   954             0.00            <
i4      739     3       >       0       805             1.00            <
i4      739     3       >       0       1058            1.00            <
i4      742     3       >       5000    537             0.00            <
i4      744     3       >       0       780             1.00            <
i4      744     3       >       0       940             1.00            <
i4      746     3       >       0       845             1.00            <
i4      748     3       >       6800    1028            0.00            <
i4      748     3       >       0       645             0.00            <
i4      750     3       >       0       996             1.00            <
i4      752     3       >       5000    675             0.00            <
i4      753     3       >       0       1025            1.00            <
i4      756     3       >       0       602             0.00            <
i4      758     3       >       10800   922             1.00            <
i4      759     3       >       0       825             0.00            <
i4      759     3       >       0       1038            0.00            <
i4      762     3       >       5000    608             1.00            <
i4      764     3       >       0       938             0.00            <
i4      766     3       >       0       797             1.00            <
i4      766     3       3200    6800    1056            1.00            6
i5      766     20      3200    3800    1156            0.00            20
i6      766     40      14000   956             0.50
e


</CsScore>

</CsoundSynthesizer>

